window.Gleam.initSearch([{"doc":"mote","title":"mote","content":"# mote\r\n\r\nA gleam executable bundler.\r\n\r\n# Installation:\r\n- Download a release of `mote`, and make it accessible for your project (either in the project directory, on your path, etc)\r\n- Install [`warp-packer`](https://github.com/dgiagio/warp/tree/master) and make it accessible as well (recommended to put it on the path)\r\n- Create a folder somewhere containing at least one erlang runtime, and add it to the environment variable `GLEAM_MOTE_RUNTIMES`\r\n  - Example runtime folder:\r\n```\r\nerlang_runtimes/\r\n- windows_x64/\r\n  - bin/\r\n  - erts-14.0.1/\r\n  - ...\r\n- linux_x64/\r\n  - bin/\r\n  - erts-14.0.1/\r\n  - ...\r\n```\r\n  - Example envvar:\r\n      - `SET GLEAM_MOTE_RUNTIMES=C:\\users\\madelline\\erlang_runtimes`\r\n   \r\n# Usage:\r\nIn your project&#39;s root directory, run `mote --runtime &lt;RUNTIME&gt;` to pack your project with the given runtime.\r\nAdd the `--target` flag (options `windows-x64`, `macos-x64`, `linux-x64`) to pack for a target other than your current environment.\r\n\r\nIn your `gleam.toml` file, you can add extra options to strip out unnecessary components (this can net you a 90+% reduction in executable size! Primarily via the lib whitelist)\r\nThis example setup will reduce your setup to more or less the minimal possible components:\r\n```toml\r\n[mote]\r\nbin_whitelist = [\r\n    &quot;erl.exe&quot;,\r\n    &quot;launch.escript&quot;,\r\n    &quot;launch.exe&quot;,\r\n    &quot;no_dot_erlang.boot&quot;,\r\n]\r\nerts_bin_whitelist = [\r\n    &quot;beam.smp.dll&quot;,\r\n    &quot;erlexec.dll&quot;,\r\n]\r\nlib_whitelist = [\r\n    &quot;compiler&quot;,\r\n    &quot;kernel&quot;,\r\n    &quot;stdlib&quot;,\r\n]\r\n```\r\n\r\nThis does remove many components of the erlang runtime that might be necessary depending on what you were doing. For example, the lib whitelist is stripping out libraries such as `xmerl` that are used for xml handling.\r\nThe erts bin whitelist is removing components such as `heart` which are presumably necessary for the heartbeat functionality of the erlang runtime.\r\nHowever, for &quot;normal&quot; apps, many of these components should be unnecessary.\r\n","url":"index.html"},{"doc":"mote/toml","title":"GetError","content":"pub type GetError {\n  NotFound\n  InvalidValue\n}\n\nNotFound\n\n\nInvalidValue\n\n\nSynonyms:\nmote/toml.GetError\nmote/toml GetError","url":"mote/toml.html#GetError"},{"doc":"mote/toml","title":"MaybeNumber","content":"pub type MaybeNumber {\n  Integer(Int)\n  Floating(Float)\n  Nan\n  Infinity\n  NegativeInfinity\n}\n\nInteger(Int)\n\n\nFloating(Float)\n\n\nNan\n\n\nInfinity\n\n\nNegativeInfinity\n\n\nSynonyms:\nmote/toml.MaybeNumber\nmote/toml MaybeNumber","url":"mote/toml.html#MaybeNumber"},{"doc":"mote/toml","title":"ReturnTerm","content":"pub external type ReturnTerm\n\n\nSynonyms:\nmote/toml.ReturnTerm\nmote/toml ReturnTerm","url":"mote/toml.html#ReturnTerm"},{"doc":"mote/toml","title":"Section","content":"pub type Section =\n  map.Map(BitString, Value)\n\n\nSynonyms:\nmote/toml.Section\nmote/toml Section","url":"mote/toml.html#Section"},{"doc":"mote/toml","title":"SemanticError","content":"pub external type SemanticError\n\n\nSynonyms:\nmote/toml.SemanticError\nmote/toml SemanticError","url":"mote/toml.html#SemanticError"},{"doc":"mote/toml","title":"TomlError","content":"pub type TomlError {\n  Tokenize(Int)\n  Parse(Int)\n  Semantic(SemanticError)\n  BadReturn(ValidateLocation, ReturnTerm)\n}\n\nTokenize(Int)\n\n\nParse(Int)\n\n\nSemantic(SemanticError)\n\n\nBadReturn(ValidateLocation, ReturnTerm)\n\n\nSynonyms:\nmote/toml.TomlError\nmote/toml TomlError","url":"mote/toml.html#TomlError"},{"doc":"mote/toml","title":"ValidateLocation","content":"pub external type ValidateLocation\n\n\nSynonyms:\nmote/toml.ValidateLocation\nmote/toml ValidateLocation","url":"mote/toml.html#ValidateLocation"},{"doc":"mote/toml","title":"Value","content":"pub type Value {\n  MaybeNumber(MaybeNumber)\n  Binary(BitString)\n  Boolean(Bool)\n  ValueList(List(Value))\n  Table(Section)\n}\n\nMaybeNumber(MaybeNumber)\n\n\nBinary(BitString)\n\n\nBoolean(Bool)\n\n\nValueList(List(Value))\n\n\nTable(Section)\n\n\nSynonyms:\nmote/toml.Value\nmote/toml Value","url":"mote/toml.html#Value"},{"doc":"mote/toml","title":"get","content":"pub fn get(section: Map(BitString, Value), path: List(String)) -&gt; Result(\n  Value,\n  GetError,\n)\n\nSynonyms:\nmote/toml.get\nmote/toml get","url":"mote/toml.html#get"},{"doc":"mote/toml","title":"get_string","content":"pub fn get_string(section: Map(BitString, Value), path: List(\n    String,\n  )) -&gt; Result(String, GetError)\n\nSynonyms:\nmote/toml.get_string\nmote/toml get_string","url":"mote/toml.html#get_string"},{"doc":"mote/toml","title":"parse","content":"pub external fn parse(String) -&gt; Result(Section, TomlError)\n\nSynonyms:\nmote/toml.parse\nmote/toml parse","url":"mote/toml.html#parse"},{"doc":"mote/toml","title":"mote/toml","content":"","url":"mote/toml.html"},{"doc":"mote","title":"main","content":"pub fn main() -&gt; Nil\n\nSynonyms:\nmote.main\nmote main","url":"mote.html#main"},{"doc":"mote","title":"mote","content":"","url":"mote.html"}]);